//------------------------------------------------------------------------------------------------------------------------
// Procédure		:	HydroStab.sce
// Auteur			:	PERRICHON Pierre
// Date				:	02/10/2019
// Sujet			: 	Crée l'interface opération pour HYDROTUR - HydroStab solution 
// Paramétrage		:	
//						
// Autres données	:	Lance l'interface de calcul des paramètres de stabilité du régulateur de vitesse

// Sorties			:	
//						
// Modifications	:
//-------------------
// Auteur			:	PERRICHON Pierre
// Date				:	23/07/2021
// Description		:	Passage Scilab 6
//
//------------------------------------------------------------------------------------------------------------------------

	global FTBO FTBF SYS_FTBO SYS_FTBF Tsim sim TParam Param Tsim_Save TParam_Save
	global Root ModelesXcos VersionHydroStab NumFigureHydroStab Plotter HandleHydroStab txVersionScilab
	global ModeSim mModeSim ma bBusy lang ConfigPAR InitHydroStab SCI_HYDROTUR_HydroStab 


	SCI_HYDROTUR_HydroStab=get_absolute_file_path("HydroStab.sce");

	if ~isdef("HydroStablib") then  
			exec(SCI_HYDROTUR_HydroStab+"loader.sce")	 
	end


	// Récupération des variables globales dan le fichier etc\HydroStab
	//---------------------------------------------------------------------
	ficRun="Run_HydroStab.sce"
	Fic=SCI_HYDROTUR_HydroStab + "etc" + filesep() + ficRun
	if ~isfile(Fic) then
						disp("...HydroStab library is not loaded. Please, use loader.sce before");
						return
	end
	
	X=mgetl(Fic)
	lg=size(X)(1)
	for i=1:lg
		if strstr(X(i),"exec") <> "" then continue; end
		execstr(X(i)); mprintf("%s\n",X(i))       
	end

	mode(-1)
	
	funcprot(0);	// Evite les messages de redéfinition de fonctions
	
	// Chargement des textes multilingues utilisés dans HydroStab
	//---------------------------------------------------------
	exec(SCI_HYDROTUR_HydroStab+"HydroStab.txt",-1);
	exec(SCI_HYDROTUR_HydroStab+"HydroStab.cfg",-1);			// Récupère la langue française par défaut
	
	// Version Scilab
	//-----------------------------------------------------
	version_numbers = getversion('scilab');
	txVersionScilab=msprintf("%1.0f.%1.0f.%1.0f",version_numbers(1), version_numbers(2), version_numbers(3))
	VersionScilab=version_numbers(1)
	
	clc		// Nettoyage console Scilab
		
	// Fonctions de transfert en boucle ouverte FTBO et boucle fermée FTBF du procédé
	//-------------------------------------------------------------------------------

	// Paramètres administratifs
	//--------------------------
	HandleHydroStab="HYDROTUR - HydroStab Solution";
	
	NumFigureHydroStab=1512300;				// Numéro de la fenêtre graphique HydroStab
	NumFigureZN=NumFigureHydroStab+1;			// Numéro du scope Ziegler-Nichols ZN
	
	sim=[]; Tsim=[]; Tsim_Save=[]
	Param=[]; TParam=[]; TParam_Save=[]
	SYS_FTBO=[]
	SYS_FTBF=[]
	
	//Ordonnées min max du scope numérique
	//------------------------------------			
	ymin_Temp=-0.5; ymax_Temp=0.5;

	// Amplitude de l'échelon
	//-----------------------
	Amp_Ech=0.1;
	
	// Paramètre Ziegler-Nichols
	//--------------------------
	Gradient_Methode=1;	
	TitreZN="Méthode de Ziegler-Nichols";

	Tosc=0;						// Gain critique
	Kcr=0;						// Période des oscillations
	
	iter_ZN=1;					// Nombre d'itération pour la méthode de recherche automatique
	i_incr_Kcr=1;				// Incrément automatique du gain Kcr	
	M_Kcr=0;					// Mémoire Kcr
	M_Pente=0;					// Mémoire Pente
	T_max=[];V_max=[];

	Rep_ZN=[];					// Réponse indicielle

	bBusy=%f;					// Sémaphore de verrouillage de la fonction Sys_Compute. Evite les cumuls d'appel pendant son traitement

	
	
	s=%s				// Variable de Laplace

	// Couleurs
	//---------
	TColor=[2 3 5 4 6 27 1 12];				// Table de couleurs des courbes 

	Grey=[.9 .9 .9];
	ColorPID=[0.98 0.83 0.71];
	
	//clc()				// Efface la console
	
	// Import HydroStab functions in the directrory local model of the current directory
	//--------------------------------------------------------------------------------
	RootIni=pwd();		// Current directory
	
	Root = get_absolute_file_path("HydroStab.sce");
	chdir(Root);						// Changement de répertoire		
	
	ModelesXcos=Root + "XCOS_Models\"	// Répertoire des modèles XCOS

	PAR="HydroStab.par"
	FichierPAR=Root + PAR

	mprintf("\nHydroStab %s\n",VersionHydroStab)		// Affiche la version de HydroStab

	mprintf("%s : \n",TSCI_HydroStab(lang))
	mprintf("\tSCI_HYDROTUR_HydroStab=""%s""\n\n",SCI_HYDROTUR_HydroStab);	//Variable d'environnement
	
	if isfile(FichierPAR) then
								mprintf("... %s SCI_HYDROTUR_HydroStab\\%s\n\n ",TFichierPAR(lang),PAR)
								exec(FichierPAR,-1)
	else
								messerr=msprintf("...%s SCI_HYDROTUR_HydroStab\\%s !",TFichierPAR2(lang), PAR)
								messagebox(messerr, TFichierPAR3(lang), "error")
								return			//...Abandon
	end

	// Run GUI interface
	//------------------
	mprintf("\n")
	
	DelHydroStabFigure()
	
	InitHydroStab=%t
	exec(Root+"HydroStab_gui.sce",-1)
	show_window(hydrostab)	// Focus sur le graphique HydroStab
	
	// Lance le premier calcul de l'application
	//------------------------------------------

	if ~HydroStab_Load_cfg() then									
								Sys_Compute();		// Lancer la consiguration par défaut
								Tsim_Save=Tsim
								TParam_Save=TParam
	end
	
	// Vérification du nom du site au lancement
	//--------------------------------------------
	isSite();	
		
	chdir(RootIni)			// Restitue le répertoire initial

	show_window(hydrostab)	// Focus sur le graphique HydroStab

