//------------------------------------------------------------------------------------------------------------------------
// Procédure		:	HydroStab_Gui.sce
// Auteur			:	PERRICHON Pierre
// Date				:	02/10/2019
// Sujet			: 	Crée l'interface opération pour HYDROTUR - HydroStab Solution 
// Paramétrage		:	
//						
// Autres données	:	L'interface est à saisir par l'utilisateur avant lancement de la simulation
//
// Sorties			:	Paramètres de régulation calculés et affichés
//						
// Modifications	:
//-------------------
// Auteur			:	PERRICHON Pierre	
// Date				:	23/07/2021
// Description		:	Passage Scilab 6 
//
//-------------------
// Auteur			:	PERRICHON Pierre	
// Date				:	21/10/2024
// Description		:	Passage Scilab 2024.1 et reprises pour module ATOMS 
//
//------------------------------------------------------------------------------------------------------------------------

	global NumFigureHydroStab FigureHydroStab Param TParam sim Tsim hydrostab PID Tlegend TColor 
	global HandleHydroStab ma Zig InitHydroStab Taglabels0

//------------------------------------------------------------------------------------------------------------------------
// Vérification des champs de données :
// Cette procédure est appelée à chaque modification d'un  paramètre hydrulique ou Régulateur
// La routine est dans le répertoire HYDROTUR\10 - TURBINES\Utilitaires Généraux\5 - SCI Files\Utilitaires_Divers.sci
// Cette routine est commune à celle utilisée pour la lecture des fichiers SCG
//----------------------
	CallBackHydroStab=msprintf("Sys_HydroStab1(%i)",NumFigureHydroStab);

//------------------------------------------------------------------------------------------------------------------------
if InitHydroStab then

	labels1=  ["Hnom", "Leq", "Seq", "Power", "Flow", "Speed", "MR2"]; 	// Modif unité Flow PPe le 23/07/2021
	String_labels1=  ["Hnom (m)", "Leq (m)", "Seq (m2)", "Power (MW)", "Flow (m3/s)", "Speed (rpm)", "MR2 (T.m2)"]; 	

	labels2= ["Kp", "Ti", "Td", "Kd"];
	String_labels2= ["Kp", "Ti (s)", "Td (s)", "Kd"];

	labels3= ["Tw", "Ta", "Allievi"];
	String_labels3= ["Tw (s)", "Ta (s)", "Allievi"];

	labels4= ["Marge_Gain", "Marge_Phase"];
	String_labels4= [TMarge_Gain(lang), TMarge_Phase(lang)];

	// Visual application
	//-------------------	
	// -------------------------------
	// Step : Store default parameters
	// -------------------------------
	
	// ----------------------------
	// Step : Empty window creation
	// ----------------------------
	
	// Global window parameters
	//-------------------------
	global margin_x margin_y;
	global frame_w frame_h plot_w plot_h;

	// Window Parameters initialization
	//---------------------------------
	frame_w = 300; frame_h = 550;				// Frame width and height
	plot_w = 620 /*600*/; plot_h = frame_h;				// Plot width and heigh
	margin_x = 15; margin_y =35;				// Horizontal and vertical margin for elements
	defaultfont = "arial"; 						// Default Font
	axes_w = 3*margin_x + frame_w + plot_w;		// axes width
	axes_h = 2*margin_y + frame_h + 0;          	// axes height (100 => toolbar height)

	hydrostab = figure("figure_id",NumFigureHydroStab,"menubar","none");				// Create window with id=NumFigureHydroStab, no menu bar,  and make it the current one

	Plotter=gca();

	// Background and text
	//--------------------
	hydrostab.background      = -2;
	hydrostab.figure_position = [100 50];
	hydrostab.figure_name     = HandleHydroStab;
	hydrostab.resize="off"
	
	hydrostab.closerequestfcn="HydroStab_XcrossClosure(%t)"		// program to close the figure using the top-right cross.
		
	// Change dimensions of the figure
	//--------------------------------
	hydrostab.axes_size = [axes_w axes_h];
	
	// Remove Scilab graphics menus & toolbar
	//---------------------------------------
end

	// New menus
	//-----------
	
	h1 = uimenu("parent",hydrostab, "label",TFile(lang));
	h2 = uimenu("parent",hydrostab, "label",TMethodes(lang));
	h3 = uimenu("parent",hydrostab, "label","?");
	h4 = uimenu("parent",hydrostab, "label",TLangues(lang));
	
	// Populate menu: file
	//--------------------
	uimenu("parent",h1, "label",TNouveau(lang), "callback","HydroStab_Param_Def()");	
	uimenu("parent",h1, "label",TLoad2(lang), "callback","HydroStab_Load();");	
	uimenu("parent",h1, "label",TSave2(lang), "callback","HydroStab_Save();");
	uimenu("parent",h1, "label",TClose(lang), "callback", "HydroStab_XcrossClosure(%t)");
	
	// Populate menu: ...Methods
	//--------------------------
	uimenu("parent",h2, "label","Ziegler-Nichols", "callback","HydroStab_Ziegler_Nichols()");		
	uimenu("parent",h2, "label","Takahashi", "callback","HydroStab_Takahashi()");		
	
	// Menu ?
	//---------------------
	uimenu("parent",h3, "label",TComment(lang), "callback","Commentaire();");
	uimenu("parent",h3, "label",TNyquistSymetric(1+ 2*(lang-1) + Symetric), "callback","NyquistSymetrique();");
	uimenu("parent",h3, "label",Tma(i_ma), "callback","Nyquist_Switch();");
	uimenu("parent",h3, "label",THelp(lang), "callback", "OnLineHelp()");
	uimenu("parent",h3, "label","About HydroStab", "callback","HydroStab_About();");
	uimenu("parent",h3, "label","About Scilab", "callback","Scilab_About();");
	
	// Populate menu: ...Langue
	//--------------------------
	uimenu("parent",h4, "label","Français", "callback","ChangeLanguage(1)");		
	uimenu("parent",h4, "label","English", "callback","ChangeLanguage(2)");		
	
	// ---------------------
	// Step : Create a frame
	// ---------------------
	
	// Frames creation [HydroStab parameters]
	//------------------------------------
	my_frame = uicontrol("parent",hydrostab, "relief","groove", ...
		"style","frame", "units","pixels", ...
		"position",[ margin_x margin_y frame_w frame_h], ...
		"horizontalalignment","center", "background",[1 1 1], ...
		"tag","frame_control");

	// Frame title
	//------------
	my_frame_title = uicontrol("parent",hydrostab, "style","text", ...
		"string",TurbineParameters(lang), "units","pixels", ...
		"position",[30+margin_x margin_y+frame_h-10 frame_w-60 20], ...
		"fontname",defaultfont, "fontunits","points", ...
		"fontsize",14, "horizontalalignment","center", ...
		"background",[1 1 1], "tag","title_frame_control");
	
	// -------------------------
	// Step : Populate the frame
	// -------------------------
	// Adding model parameters
	//------------------------

	guih0 = frame_w;
	guih0o = 240;

	// Site
	//-------------------------------
	labels0= [TSite(lang)];	
	Taglabels0=["Site"]
	values0 = [Param.Id];
	
	l1 = 20; l2 = 100; l3 = 110;
		
	for k=1:size(labels0,2)
		uicontrol("parent",hydrostab, "style","text",...
			"string",labels0(k), "position",[l1,guih0-k*20+guih0o,l2,20], ...
			"horizontalalignment","left", "fontsize",11, ...
			"background",[1 1 1]);
     
		uicontrol("parent",hydrostab, "style","edit", ...
			"string",string(values0(k)), "position",[l3,guih0-k*20+guih0o,180,20], ...
			"callback","isSite()",...
			"horizontalalignment","left", "fontsize",11, ...
			"background",ColorPID, "tag",Taglabels0(k));
	end
	
	guih1 = 250;
	guih1o = 240;

	// Hnom - Seq - Power - Flow - Speed - MR2
	//---------------------------------------------
	values1 = [Param.Hnom,Param.Leq, Param.Seq, Param.Power, Param.Flow, Param.Speed, Param.MR2];
	
	l1 = 20; l2 = 100; l3 = 110;

	for k=1:size(labels1,2)
		uicontrol("parent",hydrostab, "style","text",...
			"string",String_labels1(k), "position",[l1,guih1-k*20+guih1o,l2,20], ...
			"horizontalalignment","left", "fontsize",11, ...
			"background",[1 1 1]);
     
		uicontrol("parent",hydrostab, "style","edit", ...
			"string",string(values1(k)), "position",[l3,guih1-k*20+guih1o,180,20], ...
			"horizontalalignment","left", "fontsize",11, ...
			"callback", CallBackHydroStab, ...							
			"background",ColorPID, "tag",labels1(k));			
	end
	
	
	// Kp - Ti - Tf - Kd
	//-----------------------------
	guih2 = 250;
	guih2o = 90;
	values2 = [sim.Kp, sim.Ti, sim.Td, sim.Kd];
	
	l1 = 20; l2 = 100; l3 = 110;
	
	for k=1:size(labels2,2)
		uicontrol("parent",hydrostab, "style","text", ...
			"string",String_labels2(k), "position",[l1,guih2-k*20+guih2o,l2,20], ...
			"horizontalalignment","left", "fontsize",11, ...
			"background",[1 1 1]);
			
		uicontrol("parent",hydrostab, "style","edit", ...
			"string",string(values2(k)), "position",[l3,guih2-k*20+guih2o,180,20], ...
			"horizontalalignment","left", "fontsize",11, ...
			"callback", CallBackHydroStab, ...				
			"background",Grey, "tag",labels2(k));
	end
	
	// Tw - Ta - Allievi
	//---------------------------
	guih3 = 150;
	guih3o = 80;
	values3 = [sim.Tw, sim.Ta, sim.rho];
	
	l1 = 20//40; l2 = 100; l3 = 110;
	
	for k=1:size(labels3,2)
		uicontrol("parent",hydrostab, "style","text", ...
			"string",String_labels3(k), "position",[l1,guih3-k*20+guih3o,l2,20], ...
			"horizontalalignment","left", "fontsize",11, ...
			"background",[1 1 1]);
     
		uicontrol("parent",hydrostab, "style","edit", ...
			"string",string(values3(k)), "position",[l3,guih3-k*20+guih3o,180,20], ...
			"horizontalalignment","left", "fontsize",11,...
			"callback", CallBackHydroStab, ...										
			"background",Grey, "tag",labels3(k));
	end

	// Marge de Gain et de Phase
	//--------------------------
	guih4 = 90;
	guih4o = 80;
	values4 = ["", ""];
	
	l1 = 20; l2 = 100; l3 = 110;
	
	for k=1:size(labels4,2)
		uicontrol("parent",hydrostab, "style","text", ...
			"string",String_labels4(k), "position",[l1,guih4-k*20+guih4o,l2,20], ...
			"horizontalalignment","left", "fontsize",11, ...
			"background",[1 1 1]);
     
		uicontrol("parent",hydrostab, "style","edit", ...
			"string",string(values4(k)), "position",[l3,guih4-k*20+guih4o,180,20], ...
			"horizontalalignment","left", "fontsize",11, ...
			"callback", CallBackHydroStab, ...							
			"background",Grey, "tag",labels4(k));
	end
		
	// Adding buttons
	//----------------
	
	// Nyquist
	//---------
	huibutton1 = uicontrol(hydrostab, "style","pushbutton", ...
		"Position",[20 70 80 20], "String","Nyquist", ...
		"BackgroundColor",[.9 .9 .9], "fontsize",11, ...
		"Callback","Sys_Nyquist()");	

	// Bode	
	//---------		
	huibutton2 = uicontrol(hydrostab, "style","pushbutton", ...
		"Position",[105 70 60 20], "String","Bode", ...
		"BackgroundColor",[.9 .9 .9], "fontsize",11, ...
		"Callback","Sys_Bode()");		
			
	// Indiciel	
	//---------	
	huibutton3 = uicontrol(hydrostab, "style","pushbutton", ...
		"Position",[172 70 80 20], "String",TIndiciel(lang), ...
		"BackgroundColor",[.9 .9 .9], "fontsize",11, ...
		"Callback","Sys_Indiciel()");	

	// PID
	//---------
	huibutton4 = uicontrol(hydrostab, "style","pushbutton", ...
		"Position",[20 45 80 20], "String","PID", ...
		"Tag", "PID", ...
		"BackgroundColor",[.9 .9 .9], "fontsize",11, ...
		"Callback","sysPID");
		
	// FT
	//---------
	huibutton5 = uicontrol(hydrostab, "style","pushbutton", ...
		"Position",[105 45 60 20], "String","FTx", ...
		"Tag", "FT1", ...
		"BackgroundColor",[.9 .9 .9], "fontsize",11, ...		
		"Callback","Sys_FT_GUI");
		
	// DEL
	//---------
	huibutton6 = uicontrol(hydrostab, "style","pushbutton", ...
		"Position",[172 45 80 20], "String","DEL", ...
		"Tag", "DEL", ...
		"BackgroundColor",[.9 .9 .9], "fontsize",11, ...		
		"Callback","Sys_DEL");
		
	InitHydroStab=%f
	










