//------------------------------------------------------------------------------------------------------------------------
// Procédure		:	ChargeurXCOS
// Auteur			:	PERRICHON Pierre
// Date				:	02/10/2019
// Sujet			: 	Charge un fichier Xcos et retourne la représentation d'état de la fonction de transfert 
// Paramétrage		:	XcosFile : Nom complet du fichier Xcos à charger
//					:	init_par : initialisation ou non des paramètres du modèle à charger
//						
// Autres données	:	

// Sorties			:	Espace d'état (A, B, C, D) de la fonction de transfert du modèle sélectionné
//						
// Modifications	:
//-------------------
// Auteur			:	
// Date				:	
// Description		:	
//
//------------------------------------------------------------------------------------------------------------------------
function [TF]=ChargeurXcos(XcosFile, Mode, init_par)

	global ModelesXcos sim

	// Chargement de Xcos et fichier de simulation
	//---------------------------------------------	
	loadXcosLibs(); loadScicos();
	importXcosDiagram(ModelesXcos + XcosFile);	// Répertoire+ Fichier

	if init_par then
	
			//---------------------------------------------------------------------			
			//Chargement des paramètres de régulation définis dans les modèles XCOS
			//---------------------------------------------------------------------
			Kp=sim.Kp
			Ti=sim.Ti
			Td=sim.Td
			Kd=sim.Kd
			Ta=sim.Ta
			Tw=sim.Tw
	
			//----------------------
			// Paramètres par défaut
			//----------------------
			Ts=sim.Ts
			Gain=sim.Gain
			aut=sim.aut	
			k=sim.k;			// Approximation n°3 du coup de bélier d'onde	
			ty=sim.ty
	end
	
	//------------------------------------------------------------
	// Constructs by linearization a linear state-space model 
	// from a general dynamical system described by a Xcos diagram	
	//------------------------------------------------------------
	
	TF = lincos(scs_m)		// Forme Espace d'état
	
	select Mode
	
		case "StateSpace"
							// Espace d'état
							//--------------							
							
		case "Laplace"
							// Fonction de transfert en par
							//-----------------------------
							TF_tmp=ss2tf(TF) 	// Retour par fonction de transfert
							// Elimination des petits coefficients proches de  %eps de la TF pour éviter les erreurs de calculs de g_margin
							//-------------------------------------------------------------------------------------------------------------
							TF=clean(TF_tmp)	
					
		else
							// Erreur dans l'appel
							//--------------------
							message='Erreur d''appel dans la fonction ""ChargeurXcos"" - Syntaxe : Mode=""StateSpace"" ou Mode=""Laplace"" '
							error(message);
	end
	
endfunction