function Gradient(Kcr)

	global ModelesXcos sim Zig PID
	global M_Kcr M_Pente iter_ZN Rep_ZN
	
	XcosFile="FTBF.zcos"
	
	mAuto_ZN=Auto_ZN
				
	// Passage en mode PID automatiquement
	//------------------------------------
	if ~PID then sysPID(); end

	//---------------------------------------------------------------------			
	//Chargement des paramètres de régulation définis dans les modèles XCOS
	//---------------------------------------------------------------------
	
	//Kcr=sim.Kp/0.6	// Gain critique
	Ti=1.e10			// Constante de temps intégrale
	Td=0				// Constante de temps dérivée
	Kd=sim.Kd			// Gain de l'action dérivée
	
	Ta=sim.Ta			// Temps de lancer mécanique
	Tw=sim.Tw			// Temps de lancer hydraulique
			
	//--------------------------------------
	// Paramètres de la simulation en cours
	//--------------------------------------
	Ts=sim.Ts
	Gain=sim.Gain
	aut=sim.aut	
	k=sim.k;			// Approximation n°3 du coup de bélier d'onde	
	ty=sim.ty

	//-----------------------------------------
	
	Tosc=1			// Période des oscillation
	Vaild_ZN=%f		// Calcul Kp, Ti, Td non validé
	
	Prelude=1			// Pas d'impression du prélude dans le préliminaire du fichier "Méthode de Ziegler-Nichols.zcos"	
	
	// Chargement dans XCOS du modèle Ziegler-Nichols
	//--------------------------------------------------
	loadXcosLibs(); loadScicos();
	importXcosDiagram(ModelesXcos + XcosFile);	// Répertoire + Fichier + mise à jour structure scs_m
	
	t=0:dt_Ech:TSimZN				// Echantillonnage du circuit Xcos
	in = ones(t)					// Eléments pour réponse indicielle
	in = in* Amp_Ech;
	Rep_ZN.time=t

	//First batch simulation with the parameters embedded in the diagram
	//------------------------------------------------------------------- 
	Calcul_ZN=%t
	Valid_ZN=%f
	
	T_Kcr=[];T_Dif=[]
	
	M_Kcr=0						// Mémoire Kcr
	M_Pente=0					// Mémoire Pente
	i_incr_Kcr=1				// Incrément automatique du gain Kcr	
	
	drawlater()	
	
	f=scf(NumFigureZN)	
	f.figure_name=TitreZN
	f.figure_position=[300,20]	
	f.figure_size=[1000,400]	
	title(TRechercheKcr(lang))
	title color blue

	iter_ZN=1					// Nombre d'itération pour la méthode de recherche automatique

	while Calcul_ZN
	
				Kp=Kcr
				
				drawlater()			
				
				ftbf=lincos(scs_m)
				Rep_ZN.values=csim(in, Rep_ZN.time, ftbf );

				if mAuto_ZN<>Auto_ZN then iter_ZN=1; ClearCurves(); end

				[xxx, len_Tcolor]=size(TColor)
				len_Tcolor=5
				
				i_couleur=3 		//Rouge
				
				if Auto_ZN then i_couleur=modulo(iter_ZN,len_Tcolor)+1; end
				
				plot2d(Rep_ZN.time' , [in' Rep_ZN.values'],style=[6 TColor(i_couleur)]);
				
				[Tosc, Pente, Ecart]=Plot_Max_Reglin(Kcr)
				
				if Auto_ZN then
								// Recherche automatiqque dans la méthode ZN
								//------------------------------------------
								[Kcr, Auto_ZN]=ZN_Optimize(Kcr, Pente, Ecart);
								continue
				end
		
				// Interface opérateur
				//--------------------
									
				[BP, Valid_ZN]=ZN_GUI_1(Kcr, Tosc, Pente, Ecart); 
				
				select BP
				
					case 1 then
								// Passage en mode automatique
								//----------------------------
								Auto_ZN=%t
								mAuto_ZN=Auto_ZN
								ClearCurves()
				
					case 2 then
								// Saisir une nouvelle valeur Kcr
								//-------------------------------
								Kcr=ZN_GUI_2(Kcr)
								ClearCurves()
								
					case 3 then		
								// Validation
								//-----------
								Calcul_ZN=%f
								
					else 
						// Abandon
						//--------
						Calcul_ZN=%f				
				end	
				
	end

	// Suppression de la fenêtre graphique Ziegler-Nichols
	//----------------------------------------------------	
	close(NumFigureZN)
	
	if Valid_ZN then
					// Rajoute une FT
					//---------------
					Zig=%t				// Set indicateur Ziegler-Nichols (pour Sys_Compute)
					Load_PID_IHM()

					Sys_Compute()
	end

endfunction

