//------------------------------------------------------------------------------------------------------------------------
// Procédure		:	HydroStab_Load
// Auteur			:	PERRICHON Pierre
// Date				:	02/10/2019
// Sujet			: 	Chargement d'un fichier de paramétrisation 
//					:	Reconstitution de l'espace d'état pour chaque fonction de transfert
//					:	Lancement d'une simulation 
// Paramétrage		:	
//						
// Autres données	:	
//
// Sorties			:	
//						
// Modifications	:
//-------------------
// Auteur			:	PERRICHON Pierre
// Date				:	09.05.2020
// Description		:	Sauvegarde du dernier travail dans le répertoire de HydroStab.sce
// Description		:	- Si size(varargin)==0 (Appel sans argument d'entrée, il s'agit d'un HydroStab_Load à partir 
//						du menu HydroStab Load
//						- Si size(varargin)>0, il s'agit d'un rechargement de la dernière session HydroStab
//						Dans ce cas, varargin(1 est une chaine de caractère pointant vers le dernier travail
//						- Si size(varargin)=2, il s'agit d'un rechargement suite  à la suppression d'une FT (voir Sys_DEL)
//						Dans ces 2 derniers cas, varargin(1) est une chaine de caractère pointant vers le dernier travail
//
//------------------------------------------------------------------------------------------------------------------------
function [succes]=HydroStab_Load(varargin)

// lecture d'un fichier d'optimisation
//------------------------------------

	global	TParam Param Tsim sim PID FTBO SYS_FTBO FTBF SYS_FTBF ModeSim mModeSim HandleHYdroStab bBusy 
	global	Tsim_Save TParam_Save 
	
	succes=%f
	
	if bBusy then return; end;		// Sémaphore d'accès à Sys_Compute	
	
	EnteteHydroStab="HydroStab -"

	// Sélection du répertoire de sauvegarde
	//--------------------------------------

	directory=pwd();									// Répertoire courant	
												// Pour affichage console Scilab
	if size(varargin)>0 then	
				ParFile=varargin(1)						// Chargement du dernier travail ou du fichier tampon si action DEL en cours
	else
	
		try
			ParFile = uigetfile(["*.par"],directory, "HydroStab_Load : " + TLoad(lang), %f);
			if ParFile=="" then return; end;
		catch
			message=msprintf("... %s !", ErrDirectory(lang))
			messagebox(message, "HydroStab_Load", "warning","modal")
			return
		end
	end
	
	DEL=%f
	AFF=%t
	if size(varargin)>=2 then DEL=%t; end				// Réouverture dans ce cas du fichier intermédaire suite à suppression d'une FT
	if size(varargin)>=3 then AFF=%f; end				// Exécution en mode silencieux		
	
	[path,fname,extension]=fileparts(ParFile)
	
	if ~DEL then
	
		for i=1:1
					// Filtrage sur le nom de fichier avant ouverture
					//-----------------------------------------------
					EnteteF=part(fname,1:length(EnteteHydroStab))
					if(EnteteF<>EnteteHydroStab) then break; end;
					
					// Extraction de l'index d'enregistrement
					//---------------------------------------					
					lg=length(fname)
					n=part(fname,lg-2:lg)
				
					if ~isnum(n) then break; end;
					
					mprintf("\n...Load HydroStab File Parameters :\n %s\n",ParFile)
					
					// Rajoute le nom de fichier dans la barre d'informtion de la fenêtre
					//---------------------------------------------------------------------
					f=scf(NumFigureHydroStab);
					f.figure_name=HandleHydroStab + " - " + TFile2(lang) + " : "+ fname + extension		
					f.tag=ParFile					
					
					chdir(path)
					
					succes=%t
		end

		if ~succes then
					messerr=msprintf("...\\ %s.%s %s !",fname, extension, ErrDirectory2(lang) )
					messagebox(messerr, "HydroStab_Load", "error","modal")
					return
		end
		
	end

	//---------------------------------------------	
	// Reconstitution du système d'état de HYDROTUR
	//---------------------------------------------
	
	//--------------------------------------	
	// Chargement du fichier de paramétrage
	//--------------------------------------
	TParam=[]; Param=[];
	Tsim=[]
	exec(ParFile,0)				// Chargement du fichier de paramétrage
	
	[nbFT,x]=size(Tsim)
	
	//Rajout des champs "Comment" si nécessaire (Compatibilté ascendante)
	//-------------------------------------------------------------------
	try
			Comment=TParam(1).Comment
	catch
	end
			
	if ~isdef("Comment") then
						TParam.Comment=""	// Rajoute le champ commentaire dans toutes les structures
	end	
				
	//Prise en compte des formats d'affichage du PID
	//----------------------------------------------
	for i=1:nbFT
	
			// Rajoute table des paramètres hydrauliques si besoin (compatibilité ascendante
			//------------------------------------------------------------------------------
			sim=Tsim(i)	
			Init_FormatPID()
			Tsim(i)=sim			
	end
	
	SYS_FTBO=[]
	SYS_FTBF=[]
	
	bool=%t				// %t pour tout recalculer à l'init

	for i=1:nbFT

				Param=TParam(i)
				sim=Tsim(i)
				
				if  bool then					
											// Gestion compatibilité ascendante HydroStab 1.4
											//--------------------------------------------
											[Res] = SolveurHydroStab(Param.Hnom, Param.Leq, Param.Seq, Param.Power, Param.Flow, Param.Speed, Param.MR2)
											
											sim.Tw=Res(5); sim.Ta=Res(6); sim.rho=Res(7); sim.k=Res(8)
				end				

				// Fonctions de transfert en Boucle Ouverte
				//-----------------------------------------
				FTBO=ChargeurXcos("FTBO.zcos", "Laplace", %t)
				
				if bool then
											// Gestion compatibilité ascendante HydroStab 1.4
											//--------------------------------------------
											[MargeGainG,MargeGainF]=g_margin(FTBO)
											[MargePhaseP,MargePhaseF]=p_margin(FTBO)

											Print_sim_G_P_Marge(MargeGainG, MargeGainF, MargePhaseP, MargePhaseF)
											
											//Init_FormatPID()	
											
											Tsim(i)=sim

				end
				
				Display_Results()											
								
				SYS_FTBO=[SYS_FTBO;FTBO]

				// Fonctions de transfert en Boucle Fermée
				//-----------------------------------------
				FTBF=ChargeurXcos("FTBF.zcos", "StateSpace", %t)				
				SYS_FTBF=[SYS_FTBF;FTBF]	
			
	end
				

	Set_FT_Button(1)			// Pointer la FT n°1
	mModeSim=-1	
	sim=Tsim(1); Param=TParam(1)

	Load_Param_IHM()			// Restitution de l'IHM avec Param

	Load_PID_IHM()				// Restitue les paramètres (Kp, Ti, Td, Kp) de la dernière simulation

	// Replace la variable PID en fonction de la coloration
	//----------------------------------------------------
	PID=%t
	Colorize_PID__Button()		// Coloration en conséquence
	
	if AFF then
				Sys_Compute()	// Relance la dernière simulation sauvegardée
	end
		
	// Sauvegarde du dernier travail enregistré dand le fichier de configuration "HydroStab.cfg" et le la configuration chargée
	//----------------------------------------------------------------------------------------------------------------------
	if ~DEL then
				HydroStab_Save_cfg(path, fname+extension)	// PPe 09.05.2020	
				Tsim_Save=Tsim; TParam_Save=TParam;
	end	
	
endfunction

//--------------------------------------------------------------------------------------------------------------------------------------------------------------
