//------------------------------------------------------------------------------------------------------------------------
// Procédure		:	HydroStab_Save
// Auteur			:	PERRICHON Pierre
// Date				:	02/10/2019
// Sujet			: 	Sauvegarde d'une configuration machine et espaces d'état créées FTBO et FTBF 
// Paramétrage		:	
//
// Description		:	- Si size(varargin)==0 (Appel sans argument d'entrée, il s'agit d'une sauvegarde normale 
//					;	
//					;	- Si size(varargin)>0, il s'agit d'une sauvegarde suite à la suppression d'une FT (voir Sys_DEL
//					:	   Dans ce cas, la sauvegarde est partielle (pas d'enregistrement du fichier ".SCG"
//					:	
// Autres données	:	Dans la routine, valeurs de ModeSave, renseigné par l'interface IHM
//					:	ModeSave = 1 		==> Enregistrer sous le fichier en cours
//					: 	ModeSave = 2		==> Enregistrement avec nouvelle numérotation (Ajout d'un fichier)	
//					: 	ModeSave = 3		==> Abandon opérateur	
//					!
// Sorties			:	Données enregistrés dans un fichier numéroté . PAR avec en entête le nom du site
//					:	retour nom du fichier comlet
//						
// Modifications	:
//-------------------
// Auteur			:	PERRICHON Pierre
// Date				:	09.05.2020
// Description		:	Sauvegarde du dernier travail dans le répertoire de HydroStab.sce
//
// Modifications	:
//-------------------
// Auteur			:	PERRICHON Pierre
// Date				:	08.08.2021
// Description		:	Passage Scilab 6.1.1 : l'instruction xsave est bugguer pour la sauvegarde du fichier "scg" (copie d'écran avec structures
//					:	Voir bugzilla n°16737 : xsave/xload craches scilab 6.1.1 when saving a figure with GUI
//					:	En conséquence, mise en place d'un booléen Bug_ssave pour by-passer l'enregistrement du "scg"
//------------------------------------------------------------------------------------------------------------------------
function [xFile]=HydroStab_Save(varargin)

	// Gestion bug 16737 pour by-pass xsave
	//-------------------------------------
	Bug_xsave=%f
	if VersionScilab>=6 then Bug_xsave=%t; end
	
	// Sauvegarde d'un fichier d'optimisation
	//---------------------------------------

	global NumFigureHydroStab Param TParam Tsim ModeSim HandleHydroStab bBusy HandleHydroStab
	global Tsim_Save TParam_Save

	xFile=""
	
	if bBusy then return; end;		// Sémaphore d'accès à Sys_Compute

	EnteteHydroStab="HydroStab"	

	f=scf(NumFigureHydroStab);			// Handler de la figure

	ModeSave=2						// Mode de sauvegarde par défaut
	
	DEL=%f
	if size(varargin)>0 then 
							// Soit sauvegarde dans un fichier temporaire suite action touche DEL
							//-------------------------------------------------------------------
							DEL=%t	
	end
	
	AFF=%t
	if size(varargin)>1 then 
							 AFF=%f	// Exécution en mode silencieux
	end
	

	// Sélection du répertoire de sauvegarde
	//--------------------------------------
	directory=pwd();				// Répertoire courant
	directory2=directory
	
	Load_IHM_Param()		// Recopie de l'IHM dans la partie Param
	
	Num_FT=Get_FT_Button()
	TParam(Num_FT).Id=Param.Id
	
	if ~DEL then
	
			// Selection du mode d'enregistrement
			//-----------------------------------	
			ModeSave=Select_Save()					// Affiche l'interface IHM
			
			if ModeSave==3 then return; end			// Abandon opérateur
			
			if ModeSave==1 then
								Changement_Site= f.tag=="" | strstr(f.figure_name, Param.Id)==""	
								
								if Changement_Site then ModeSave=2; end			// Il s'agit donc de la configuration par défaut ou d'un changement de répertoire
			end
	
			if ModeSave==2 then
								try	
									directory2=uigetdir(directory,"Save HydroStab : " + TSave(lang) )
									if directory2=="" then return; end;
								catch
									message=msprintf("... %s !", ErrDirectory(lang))
									messagebox(message, "HydroStab_Save", "warning","modal")	
									return
								end
			
								chdir(directory2);
			end
			
	end
	
	Entete2=msprintf("%s - %s - ", EnteteHydroStab , Param.Id)		

	if ModeSave==1 then
					 // Sauvegarde sur le fichier en cours
					 //------------------------------------
					[directory2,NomFic,z]=fileparts(f.tag)
					chdir(directory2)
					directory2=strncpy(directory2,length(directory2)-1)		// Supprime caractère "\"
				
					Numreg=strrchr(NomFic,"-");								// Récupérer le n° de l'enregistrement 
					Numreg=strsubst(Numreg,"-","")
					Numreg=evstr(Numreg)									// Conversion ASCII==> Integer					
	else
					// Recherche du numéro d'enregistrement
					//-------------------------------------
					Numreg=1;
					ListEnreg=listfiles(["*.par"])
					[lg,x]=size(ListEnreg)
					

					// Lire les fichiers HydroStab existant pour déterminer le n° d'enregistrement
					//-----------------------------------------------------------------------------		
					for i=1:1:lg
								RegName=ListEnreg(i)
								if strstr(RegName,Entete2)=="" then continue; end;
					
								[path,fname,extension]=fileparts(RegName)
					
								// Extraction de l'index d'enregistrement
								//---------------------------------------	

								n=strrchr(fname,"-");						// Récupérer le n° de l'enregistrement 
								n=strsubst(n,"-","")
								if ~isnum(n) then continue; end;

								n=evstr(n)									// Conversion ASCII==> Integer					
								
								if Numreg<=n then Numreg=n+1; end;			// Nouvel index						
					end
					
					// Créer le nom des fichiers de sauvegarde
					//-----------------------------------------					
					NomFic=msprintf("%s - %s - %02i", EnteteHydroStab, Param.Id, Numreg)							
	end
	
	NomFic1= NomFic + ".par"
	
	// Rajoute le nom de fichier dans la barre d'informtion de la fenêtre
	//---------------------------------------------------------------------	
	if AFF then mprintf("\n...Save HydroStab File Parameters : %s\n",NomFic1); end

	if ~DEL then 
				f.figure_name=HandleHydroStab + " - Fichier "+ NomFic1	
				f.tag= directory2 + "\" + NomFic1
	end
			
	// Sauvegarde des paramètres machine
	//---------------------------------
	fd = mopen(NomFic1,'wt');

	//Sauvegarde des paramètres de simulation
	//---------------------------------------	
	[lg,x]=size(Tsim)
	
	for i=1:lg
		// Paramètres hydrauliques
		//------------------------
		mfprintf(fd,"TParam(%i).Id=""%s"";\n",i, TParam(i).Id);
		mfprintf(fd,"TParam(%i).Comment=""%s"";\n\n",i, TParam(i).Comment);
		mfprintf(fd,"TParam(%i).Hnom=%f;\n",i, TParam(i).Hnom);
		mfprintf(fd,"TParam(%i).Leq=%f;\n",i, TParam(i).Leq);
		mfprintf(fd,"TParam(%i).Seq=%f;\n",i, TParam(i).Seq)
		mfprintf(fd,"TParam(%i).Power=%f;\n",i, TParam(i).Power);
		mfprintf(fd,"TParam(%i).Flow=%f;\n",i, TParam(i).Flow);
		mfprintf(fd,"TParam(%i).Speed=%f;\n",i, TParam(i).Speed);
		mfprintf(fd,"TParam(%i).MR2=%f;\n",i, TParam(i).MR2);
	
		mfprintf(fd,"\n")		
	
		// Paramètres du régulateur de vitesse
		//------------------------------------
		mfprintf(fd,"Tsim(%i).Kp=%0.4f;\n",i,Tsim(i).Kp)
		mfprintf(fd,"Tsim(%i).Ti=%0.4f;\n",i,Tsim(i).Ti)
		mfprintf(fd,"Tsim(%i).Td=%0.4f;\n",i,Tsim(i).Td)
		mfprintf(fd,"Tsim(%i).Kd=%0.4f;\n",i,Tsim(i).Kd)
		
		mfprintf(fd,"Tsim(%i).Tw=%0.4f;\n",i,Tsim(i).Tw)
		mfprintf(fd,"Tsim(%i).Ta=%0.4f;\n",i,Tsim(i).Ta)
		mfprintf(fd,"Tsim(%i).rho=%0.4f;\n",i,Tsim(i).rho)
		mfprintf(fd,"Tsim(%i).k=%f;\n",i,Tsim(i).k)
		mfprintf(fd,"Tsim(%i).Ts=%f;\n",i,Tsim(i).Ts)
		mfprintf(fd,"Tsim(%i).aut=%f;\n",i,Tsim(i).aut)
		mfprintf(fd,"Tsim(%i).Gain=%f;\n",i,Tsim(i).Gain)
		mfprintf(fd,"Tsim(%i).ty=%f;\n",i,Tsim(i).ty)
		
		mfprintf(fd,"Tsim(%i).GMarge=""%s"";\n",i,Tsim(i).GMarge)
		mfprintf(fd,"Tsim(%i).PMarge=""%s"";\n",i,Tsim(i).PMarge)
		mfprintf(fd,"\n\n")
	end

	// Paramètre de la dernière simulation
	//------------------------------------
	mfprintf(fd,"\nModeSim=%i;\n",ModeSim)
	
	mclose(fd);

	if ~DEL then
	
			// Sauvegarde du graphique
			//------------------------
			trouve=%f
		
			// Recherche du graphique HydroStab si plusieurs graphiques (scope) sont affichés dans la fenêtre Scilab
			listfigs=winsid()
			[x, lg]=size(listfigs);
	
			for i=1:lg
							f=scf(listfigs(i))
							name=f.figure_name
							if strstr(name,HandleHydroStab)<>"" then trouve=%t; end;
			end

			messagex=msprintf("%s :\n\n %s \n\n%s : \n\n %s ", TFile2(lang), NomFic1, TRepertoire(lang), directory2); 
			messagebox([messagex] , "HydroStab_Save", "info", "modal");
		
			mprintf("\n%s :\n%s\n",TRepertoire(lang), directory2);
			mprintf("\n...HydroStab_Save %s :\n %s\n", TFile2(lang), NomFic1);
	
			// Sauvegarde du dernier travail enregistré dand le fichier de configuration "HydroStab.cfg"
			//---------------------------------------------------------------------------------------
			HydroStab_Save_cfg(directory2, NomFic1)	// PPe 09.05.2020	
			
			Tsim_Save=Tsim; TParam_Save=TParam;
			
	end

	chdir(directory2)
	
	xFile=directory2 +  "\" + NomFic1	
	
endfunction
