
//------------------------------------------------------------------------------------------------------------------------
// Procédure		:	Nyquist
// Auteur			:	PERRICHON Pierre
// Date				:	22/10/2019
// Sujet			: 	Affichage des fonctions de tranfert dans le plan de Nyquist
//					:	Appel normal avec des FTBO pour l'application, soit l'emplilement dans SYS_FTBO
// Paramétrage		:	
//						
// Autres données	:	FTBO est la représentation de la fonction de transfert en représentation d'état (A, B, C, D)
//					:	Dessine les équipotentielles 3dB, 0dB, -3dB
//					:	Dessine la marge de module et le point P en couleur magenta
//					:	Scilab 5.5.2
//					:	
//
// Sorties			:	
//						
// Modifications	:
//-------------------
// Auteur			:	PERRICHON Pierre
// Date				:	27.02.2020
// Description		:	Modification pour la fonction isoview Scilab 6.1.0
//
//------------------------------------------------------------------------------------------------------------------------

function Nyquist()

	global SYS_FTBO FTBO

	drawlater();

	//---------------------------- Fréquentiel
	TraceNyquist();

	PPe_show_margins(FTBO,'nyquist');

	if  VersionScilab < 6 then
				isoview(-1.0,1.0,-1.0,1.0);				// PPe 27.02.2020

	else
				isoview									// PPe 27.02.2020
				replot([-1.0,-1.0,1.0,1.0])
	end
		
	drawnow()

endfunction

//------------------------------------------------------------------------------------------------------------------------
// Procédure		:	TraceNyquist
// Auteur			:	PERRICHON Pierre
// Date				:	22/10/2019
// Sujet			: 	Affichage des fonctions de tranfert dans le plan de Nyquist
//					:	Appel normal avec des FTBO pour l'application, soit l'emplilement dans SYS_FTBO
// Paramétrage		:	
//						
// Autres données	:	FTBO est la représentation de la fonction de transfert en représentation d'état (A, B, C, D)
//					:	Dessine les équipotentielles 3dB, 0dB, -3dB
//					:	Dessine la marge de module et le point P en couleur magenta
//					:	Chaque courbe est tracée par une boucle sur le nombre de TF
//					:	Courbes limitées par l'isoview et les bounds, ce qui est un avantage
//					: 	oar rapport à la fonctio nyquist du consortium qui fait un tracé en dehors de l'isoview
//					:	(fmin et fmax) calculés par	nyquistfrequencybounds
//
// Sorties			:	
//						
// Modifications	:
//-------------------
// Auteur			:	
// Date				:	
// Description		:	
//
//------------------------------------------------------------------------------------------------------------------------
function TraceNyquist()

	global Tlegend SYS_FTBO
	
	Symetrique=Symetric>0
	
	bounds=[-1.0 -1.0;1.0 1.0];

	AddLegend()		// Construction de la table des légendes	
	Curves=[]	

	[nbFT,x]=size(SYS_FTBO)
	
	for i=1:nbFT
			try
					[fmin, fmax]=nyquistfrequencybounds(SYS_FTBO(i,1),bounds);
					
					//Ecrétage des valeurs fmin et fmax
					//----------------------------------
					if fmin<fmin_n then fmin=fmin_n;end;
					if fmax==%inf | fmax>fmax_n then fmax=fmax_n;end;		

					xCurves=Nyquist_PPe(SYS_FTBO(i,1),fmin,fmax,Symetrique);
		
					Curves=[Curves;xCurves]

					PaintNyquist(i);		
					
			catch
					[str,numerror,line,func]=lasterror();					
					mprintf("...Warning TraceNyquist\n%s n°%i %s %s=%i fonction=%s\n\n",TErr100(lang), numerror,str, TLigne(lang), line,func);
					
					f=scf(NumFigureHydroStab);	
					[path, fname, extension] = fileparts(f.tag);
					fname=fname+extension;
					mes1=msprintf("...%s ""%s""",TErr120(lang), fname);
					mes2="..." + TErr121(lang) +  "!";
					messagebox([mes1; ""; mes2], "Nyquist.sci", "error","modal");						
			end
	end

	legend(Curves,Tlegend,opt=1,with_box=%f)
	
endfunction

//------------------------------------------------------------------------------------------------------------
function PaintNyquist(numCourbe)

// Coloration de la courbe de Nyquist
//-----------------------------------
	
		ax=Plotter
		//disp(ax, "ax")
		//disp("...................")
		
		child1=ax.children(1)		
		//disp(child1, "chidren1")	//composant
		
		child2=child1.children(1)
		//disp(child2, "chidren2")	//composant

		child3=child2.children(1)
		//disp(child3, "chidren3")	//matrix
		
		len=size(child3.children)
		//disp(len(1), "len")
		
		for k=1:1:len(1)
				child3.children(k).foreground=TColor(numCourbe); // Coloration des flèches
		end

		child4=child2.children(2)
		//disp(child4, "chidren4")	//matrix
		len=size(child4.children)
		//disp(len(1), "len")
		
		for k=1:1:len(1)
				child4.children(k).font_foreground=TColor(numCourbe); // Coloration des textes
		end
		
		child10=ax.children(1)		
		//disp(child10, "chidren10")	//composant
	

		child22=child10.children(2)	// Coloration Courbes de Nyquist
		//disp(child22, "chidren22")	//
		child22.foreground=TColor(numCourbe)
endfunction
