//------------------------------------------------------------------------------------------------------------------------
// Procédure		:	SolveurHydroStab
// Auteur			:	xxx  (Collaboration Turbinier + Ecole)
// Date				:	1978
// Sujet			: 	Calcule les paramètres du PID vitesse pour que le Nyquist passe par le point P 
//                   : 	Méthode Marge de module
// Paramétrage		:	
//						
// Autres données	:	On fixe le rayon de stabilté ma dans le plan de Nyquist
//					: 	les angles des actions intégrale et dérivée	
//					: 	et on calcule en sorties le quadrulet (Kp, Ti Td, Kd) du PID à rajouter
//
//					:	Chargement du process "FTBO.zcos" avec débrayage du PID vitesse
//
// Sorties			:	Kp, Ti Td, Kd, Ta, Tw, Allievi k (paramétrage boite turbine/adduction)
//						
// Modifications	:
//-------------------
// Auteur			:	PERRICHON Pierre
// Date				:	02/10/2019	
// Description		:	Intégration dans le projet HYDROTUR
//
//------------------------------------------------------------------------------------------------------------------------
function [Out]=SolveurHydroStab(Hnom, Leq, Seq, Power, Flow, Speed, MR2)

	global sim ma 

//Données secondaires
//--------------------

	Kd=sim.Kd	 		// Gain de l'accéléromètre
	// Limitation du gain de l'action dérivée Kd
	//------------------------------------------
	Kd=max(Kd,Vmin_Kd)
	
	aut=sim.aut			// Coefficient d'autoréglage du réseau	
	Ts=sim.Ts;			// constante de temps du système copiant (ordre 1*ordre 1)
	ty=sim.ty;			// constante de temps de filtrage du tachymètre
	Gain=sim.Gain;		// gain puissance/ouverture
	
	k=(2*Leq/(1000*%pi))^2;		// Coefficient Turbine/Adduction
	
//	ma=0.42;			// Rayon de stabilité (domaine pratique:[+eps à 0.707])

	ai=0.349;			// radian	angle action intégrale régulateur
	ad=0.1745;			// radian	angle action dérivée régulateur

// Autres données
//---------------	
	g=9.81;				// Accélération de la pesanteur		
	a=1000;				// Célérité de l'onde d'eau
	rho=1000;			// Masse volumique de l'eau
		
	ine=MR2*1000;		// Conversion Inertir T.m^2 en kg.m^2	

// Calcul Tw, Ta, Allievi
//-----------------------
	om0=Speed/60*2*%pi;
	wn=Power*1.e6;

	// Calcul du rendement pour information
	//--------------------------------------
	eta=wn/(Flow*rho*g*Hnom);	// Calcul du rendement	
	//mprintf("eta=%04f\n",eta);

	Ta=ine*om0^2/wn;
	Tw=Leq*Flow/(g*Hnom*Seq);
	Allievi=Tw*a/(2*Leq);
	
	//-------------------------------------------------------------------------------------------------------
	// Laisser les instructions ci-dessous pour éviter tout bug dans la fonction g_margin utilisée plus loin
	//-------------------------------------------------------------------------------------------------------
	//precision="%0.12f"	
	precision=Format04
	
	sTw=msprintf(precision,Tw)		// Limitation Tw
	Tw=evstr(sTw)
	sTa=msprintf(precision,Ta)		// Limitation Ta
	Ta=evstr(sTa)
	
// Calcul des données
//--------------------
	r=(Kd-1)/(Kd+1);

	t=tan(ad);
	d=r*r*(1+t*t)-t*t;
	c2a=(t*t+d^0.5)/(r*(1+t*t));
	ca=((c2a+1)/2)^0.5;
	sa=((-c2a+1)/2)^0.5;
	s=(Kd-1)*ca*sa/(sin(ad)*cos(ai));	// gain régulateur au point P (avec Kp=1)
	v=Kd*sa/ca;							// v=tn*(pulsation au point P)

	rop=(ma*ma-ma*2^0.5+1)^0.5;			// module du point p
	ap=atan(ma/((2)^0.5-ma));			// angle du point p 

	app=-(%pi-ap-ai+ad);				// phase process (radian) au point P


// Calcul des paramètres du régulateur de vitesse
//-----------------------------------------------

	// Débrayge du PID vitesse dans la FTBO
	//-------------------------------------
	Ti=1.e10		// Constante de temps intégrale
	Td=0			// Constante de temps dérivée
	Kd=sim.Kd		// Gain de l'aaction dérivée
	Kp=1

	
	Sys=ChargeurXcos("FTBO.zcos", "Laplace", %f)

	
	OM=(0.001:0.005:3);

	//bode(Sys)

	frq=OM/(2*%pi); 				
	[frq1,rep] =repfreq(Sys,frq);
	[db,phi]=dbphi(rep);

	phi=phi*%pi/180;								//phase en radians
	omp=interp1(phi,OM,app,'linear');				//interpolation pour obtenir la pulsation en app
 
	[frq1,rep] =repfreq(Sys,omp/(2*%pi));
	[db,phi]=dbphi(rep);
	ampl=exp(db*log(10)/(20)); 
 
	Ti=1/(omp*tan(ai));		// Constante de temps de l'intégrateur
	Td=v/omp;				// Constante de temps du dérivateur
	Kp=1/(s*ampl/rop);		// Gain du régulateur

	xx=msprintf(Format04,Kp);			Kp=evstr(xx)
	xx=msprintf(Format04,Ti);			Ti=evstr(xx)
	xx=msprintf(Format04,Td);			Td=evstr(xx)
	xx=msprintf(Format04,Kd);			Kd=evstr(xx)
	xx=msprintf(Format04,Tw);			Tw=evstr(xx)
	xx=msprintf(Format04,Ta);			Ta=evstr(xx)
	xx=msprintf(Format04,Allievi);		Allievi=evstr(xx)
	xx=msprintf(Format04,k);			k=evstr(xx)
	
	// mprintf("***Kp=%f Ti=%f Td=%f Kd=%f\n", Kp, Ti, Td, Kd);	
 
	Out = [Kp; Ti; Td; Kd; Tw; Ta; Allievi; k];

endfunction


