//------------------------------------------------------------------------------------------------------------------------
// Procédure		:	Sys_Compute
// Auteur			:	PERRICHON Pierre
// Date				:	02/10/2019
// Sujet			: 	Introduit une nouvelle fonction de transfert dans la liste des fonction de transfert
//					:	Routine principale d'interfaçage dans toute l'application
// Paramétrage		:	
//						
// Autres données	:	

// Sorties			:	Paramètres de régulation calculés et affichés
//						
// Modifications	:
//-------------------
// Auteur			:	
// Date				:	
// Description		:	
//
//------------------------------------------------------------------------------------------------------------------------
function Sys_Compute()

	global Param sim PID ModeSim mModeSim TParam Tsim NumFigureHydroStab Plotter
	global FTBO FTBF SYS_FTBO SYS_FTBF
	global bBusy Zig

	if bBusy then return; end;
	
	// Vérification de données au format Nombres flottants avec séparateur décimal "."
	//---------------------------------------------------------------------------------
	if ~CheckValues(labels1) | ~CheckValues(labels2) then return; end; 
	
	show_window(NumFigureHydroStab)
	
	
	bBusy=%t						// Verrouillage de la séquence "Sys_Compute"

	// Effacement de la fenêtre graphique courante
	//--------------------------------------------

	PlotterErase()
		
	index=1
	found=%f

	// Calcul pour le passage au point P
	//-----------------------------------
	Load_IHM_Param()		// Copie l'IHM sur la structure "Param"	
	Load_IHM_PID()			// Copie l'IHM sur la structure "sim". En particuler, possibilité de modifié Kd	

	// Dispositif spéciale pour le gain dérivateur
	// Limitation minimale de Kd, car le Solver calcule un terme en Kd-1, passant dans un  dénominateur des calculs
	//--------------------------------------------------------------------------------------------------------------------
	if sim.Kd<Vmin_Kd then
				sim.Kd=Vmin_Kd;
				Load_PID_IHM()	// Rechargement avec valeur Kd limitée
	end
	
	// Calcul des paramètres du régulateur par la méthode de Marge de Module
	//----------------------------------------------------------------------
	[Res] = SolveurHydroStab(Param.Hnom, Param.Leq, Param.Seq, Param.Power, Param.Flow, Param.Speed, Param.MR2)	

	if ~PID then 	
				if ma==ma3dB then Param.Comment="Marge Module +3dB";
				 else Param.Comment="Marge Module -3dB"; end
				 
				sim.Kp=Res(1)
				sim.Ti=Res(2)
				sim.Td=Res(3)
				sim.Kd=Res(4)
				Load_PID_IHM()			// Pour prise en compte des formats												
	end
	
	// Pamamètres PID saisis par l'opérateur
	//--------------------------------------
	Load_IHM_PID()			// Copie l'IHM sur la structure "sim"	
	
								
	// Si le PID (FT) existe déja, on lance la simulation avec l'indice suivant (Rajout PPe le 10/11/2019)
	//----------------------------------------------------------------------------------------------------	
	[index,found]=Recherche_sim()
		
	if found  then 
						if ModeSim==mModeSim && PID then
								if index==Get_FT_Button() & ~Zig then 
											index=index+1; 		// Inspection de la FT suivante (2 appuis sur la même fonction)
								end			
								
								[lg,x]=size(Tsim)								
								if index>lg then index=1; end;	
								
						end						
	else						
						sim.Tw=Res(5); sim.Ta=Res(6); sim.rho=Res(7); sim.k=Res(8)
						
						
						if ~Zig && PID then
									Param.Comment="User"
						end


						// Calcul des fonctions de transferts FTBO et FTBF
						//-------------------------------------------------
						
						Calcul_FTB0_FTBF();			// Recalcule FTBO, FTBF, Marge de Gain et de Phase						
						
						if ~Saturation_FT() then	// Test de saturation Nombre de FT									
								// On rajoute une fonction de transfert (dans ce cas index vaut l'indice d'insertion, cf Recherche_sim())
								//-------------------------------------------------------------------------------------------------------
								mprintf("...%s\n",TAddTFR(lang))
								
								Tsim(index)=sim
								TParam(index)=Param
								SYS_FTBO=[SYS_FTBO ; FTBO]									
								SYS_FTBF=[SYS_FTBF ; FTBF]
						else
								index=Get_FT_Button()		// on reste sur la même FT
						end
	end
	
	// Modif PPe 2020.08.09
	//---------------------
	Set_FT_Button(index)		// Affichage du n° de la fonction de transfert dans le bouton FT										
	
	// Affichage des Tw, Ta, Allevi, Marges de gains et de phase de FTBO
	//------------------------------------------------------------------

	Display_Results()
	
	// Transfert de la structure Param l'IHM
	//--------------------------------------------

	Load_Param_IHM()

	// Transfert des paramètres calculés sur l'IHM
	//--------------------------------------------

	Load_PID_IHM()		// Restitue les paramètres (Kp, Ti, Td, Kp) sur l'IHM
			
	// Réajuster la fenêtre graphique
	//-------------------------------
	Plotter=gca();			// Création des axes
	Plotter.title.font_size = 2;
	Plotter.axes_bounds = [1/3,0,2/3,1];
	Plotter.tag="Plotter";

	// Tracé du lieu de Nyquist en boucle ouverte
	//--------------------------------------------
	select ModeSim
	
		case 0 then
					Nyquist()
		case 1 then
					Bode()
		else
					Temporel()
	end
	
	// Rajout des légendes
	//--------------------
	AddLegend()	
	
	PrintScilabConsole(-1)
	
		
	// Démarrage automatique du mode datatips
	//----------------------------------------
	datatipManagerMode('on')

	mModeSim=ModeSim			// Mémoire ModeSim
	
	PID=%t
	Colorize_PID__Button()		// ... on repasse en  mode PID

	bBusy=%f					// Déverrouillage du sémaphore de la séquence "Sys_Compute"
	Zig=%f						// Retombée indicateur Ziegler-Nichols

	// Affichage info_lessage dans l'écran HydroStab
	//----------------------------------------------
	Display_Info_Message()
		
endfunction

